pub struct Raw<T>(pub T);Expand description
Text that should not be escaped at runtime, such as dynamically generated html, or some content that has already been escaped.
Note, that string literals are automatically escaped at compile-time when
used within html!, therefore, one should not wrap static content with Raw in
an attempt to improve performance.
html! {
@avosetta::raw("Hello, World!")
};Tuple Fields
0: TTrait Implementations
Sourceimpl<T: Ord> Ord for Raw<T>
impl<T: Ord> Ord for Raw<T>
Sourceimpl<T: PartialOrd> PartialOrd for Raw<T>
impl<T: PartialOrd> PartialOrd for Raw<T>
impl<T: Copy> Copy for Raw<T>
impl<T: Eq> Eq for Raw<T>
impl<T> StructuralPartialEq for Raw<T>